loadWorkbook: Load Workbook

Description Usage Arguments Value Examples

View source: R/loadWorkbook.R

Description

Loads an Excel workbook using readxl and returns a lst of all the sheets.

Usage

1
loadWorkbook(workbookPath, guessVarTypes = TRUE, na = c("", "NA", "NULL"))

Arguments

workbookPath

Path and file name of the workbook.

guessVarTypes

Try to guess variable types.

na

Character vector of strings to interpret as missing data.

Value

A lst of tibbles containing the sheets of the workbook.

Examples

1
data <- loadWorkbook('data.xlsx')

JonasEngstrom/icudb documentation built on Dec. 18, 2021, 1:41 a.m.