Description Usage Arguments Value Examples
Loads an Excel workbook using readxl and returns a lst of all the sheets.
1 | loadWorkbook(workbookPath, guessVarTypes = TRUE, na = c("", "NA", "NULL"))
|
workbookPath |
Path and file name of the workbook. |
guessVarTypes |
Try to guess variable types. |
na |
Character vector of strings to interpret as missing data. |
A lst of tibbles containing the sheets of the workbook.
1 | data <- loadWorkbook('data.xlsx')
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.